==> cds4j-runtime-1.30.0-sources.jar: com/sap/cds/impl/sql/InsertStatementBuilder.java <==
/************************************************************************
 * © 2019-2022 SAP SE or an SAP affiliate company. All rights reserved. *
 ************************************************************************/
package com.sap.cds.impl.sql;

import static com.sap.cds.impl.builder.model.ElementRefImpl.parse;
import static com.sap.cds.impl.sql.SQLHelper.commaSeparated;
import static com.sap.cds.impl.sql.SQLHelper.param;
import static com.sap.cds.util.CdsModelUtils.element;
import static java.util.stream.Collectors.joining;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Stream;

import com.sap.cds.impl.Context;
import com.sap.cds.impl.PreparedCqnStmt.Parameter;
import com.sap.cds.ql.cqn.CqnElementRef;
import com.sap.cds.ql.cqn.CqnInsert;
import com.sap.cds.ql.cqn.CqnStructuredTypeRef;
import com.sap.cds.reflect.CdsElement;
import com.sap.cds.reflect.CdsEntity;

public class InsertStatementBuilder implements SQLStatementBuilder {

	private final CqnInsert insert;
	private final SqlMapping sqlMapping;
	private final CdsEntity entity;

	public InsertStatementBuilder(Context context, CqnInsert insert) {
		this.insert = insert;
		CqnStructuredTypeRef ref = insert.ref();
		entity = context.getCdsModel().getEntity(ref.firstSegment());
		sqlMapping = new SqlMapping(entity);
	}

	public SQLStatement build() {
		List<Parameter> params = new ArrayList<>();

		String tableName = sqlMapping.tableName();
		String columnsString = commaSeparated(insert.elements().map(e -> {
			CqnElementRef ref = parse(e);
			CdsElement element = element(entity, ref);
			params.add(param(e, element));
			return sqlMapping.columnName(ref);
		}));
		String ps = commaSeparated(insert.elements().map(c -> "?"));
		String sql = Stream.of("INSERT INTO", tableName, columnsString, "VALUES", ps).collect(joining(" "));

		return new SQLStatement(sql, params);
	}

}

==> cds4j-runtime-2.4.1-sources.jar: com/sap/cds/impl/sql/InsertStatementBuilder.java <==
/************************************************************************
 * © 2019-2022 SAP SE or an SAP affiliate company. All rights reserved. *
 ************************************************************************/
package com.sap.cds.impl.sql;

import static com.sap.cds.impl.builder.model.ElementRefImpl.parse;
import static com.sap.cds.impl.sql.SQLHelper.param;
import static com.sap.cds.util.CdsModelUtils.element;
import static java.util.stream.Collectors.joining;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Stream;

import com.sap.cds.impl.Context;
import com.sap.cds.impl.PreparedCqnStmt.Parameter;
import com.sap.cds.jdbc.spi.SqlMapping;
import com.sap.cds.ql.cqn.CqnElementRef;
import com.sap.cds.ql.cqn.CqnInsert;
import com.sap.cds.ql.cqn.CqnStructuredTypeRef;
import com.sap.cds.reflect.CdsElement;
import com.sap.cds.reflect.CdsEntity;

public class InsertStatementBuilder implements SQLStatementBuilder {

	private final CqnInsert insert;
	private final SqlMapping sqlMapping;
	private final CdsEntity entity;

	public InsertStatementBuilder(Context context, CqnInsert insert) {
		this.insert = insert;
		CqnStructuredTypeRef ref = insert.ref();
		entity = context.getCdsModel().getEntity(ref.firstSegment());
		sqlMapping = context.getDbContext().getSqlMapping(entity);
	}

	public SQLStatement build() {
		List<Parameter> params = new ArrayList<>();

		String tableName = sqlMapping.tableName();
		String columnsString = SQLHelper.commaSeparated(insert.elements().map(e -> {
			CqnElementRef ref = parse(e);
			CdsElement element = element(entity, ref);
			params.add(param(e, element));
			return sqlMapping.columnName(ref);
		}));
		String ps = SQLHelper.commaSeparated(insert.elements().map(c -> "?"));
		String sql = Stream.of("INSERT INTO", tableName, columnsString, "VALUES", ps).collect(joining(" "));

		return new SQLStatement(sql, params);
	}

}
